You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@jclouds.apache.org by Andrea Turli <no...@github.com> on 2016/10/13 20:11:23 UTC
[jclouds/jclouds] reduce payload for GET VirtualGuests (#1020)
Using this objectMask instead of previous, json payload passes from 69.8 M
```
$ curl -uuser:api-key https://api.softlayer.com/rest/v3/SoftLayer_Account/VirtualGuests?objectMask=powerState%3BoperatingSystem.passwords%3Bdatacenter%3BbillingItem%3BblockDevices.diskImage%3BtagReferences
% Total % Received % Xferd Average Speed Time Time Time Current
Dload Upload Total Spent Left Speed
12 145M 12 18.0M 0 0 321k 0 0:07:44 0:00:57 0:06:47 401k
```
down to
```
$ curl -uuser:api-key https://api.softlayer.com/rest/v3/SoftLayer_Account/VirtualGuests?objectMask=powerState%3BoperatingSystem.passwords%3Bdatacenter%3BbillingItem%3BblockDevices.diskImage%3BtagReferences.tag.name
% Total % Received % Xferd Average Speed Time Time Time Current
Dload Upload Total Spent Left Speed
100 277k 100 277k 0 0 77421 0 0:00:03 0:00:03 --:--:-- 77426
```
from 145 MB to 277 KB, @aledsage and @nacx wdyt?
You can view, comment on, or merge this pull request online at:
https://github.com/jclouds/jclouds/pull/1020
-- Commit Summary --
* reduce payload for GET VirtualGuests
-- File Changes --
M providers/softlayer/src/main/java/org/jclouds/softlayer/features/AccountApi.java (2)
A providers/softlayer/src/test/resources/logback-test.xml (42)
D providers/softlayer/src/test/resources/logback.xml (34)
-- Patch Links --
https://github.com/jclouds/jclouds/pull/1020.patch
https://github.com/jclouds/jclouds/pull/1020.diff
--
You are receiving this because you are subscribed to this thread.
Reply to this email directly or view it on GitHub:
https://github.com/jclouds/jclouds/pull/1020
Re: [jclouds/jclouds] reduce payload for GET VirtualGuests (#1020)
Posted by Andrea Turli <no...@github.com>.
ok merging now on master and backport to 1.9.x
thanks!
--
You are receiving this because you are subscribed to this thread.
Reply to this email directly or view it on GitHub:
https://github.com/jclouds/jclouds/pull/1020#issuecomment-253742999
Re: [jclouds/jclouds] reduce payload for GET VirtualGuests (#1020)
Posted by Andrea Turli <no...@github.com>.
Merged at [master](http://git-wip-us.apache.org/repos/asf/jclouds/commit/2c6caa04) and bacported to [1.9.x](http://git-wip-us.apache.org/repos/asf/jclouds/commit/a843196b).
--
You are receiving this because you are subscribed to this thread.
Reply to this email directly or view it on GitHub:
https://github.com/jclouds/jclouds/pull/1020#issuecomment-253744487
Re: [jclouds/jclouds] reduce payload for GET VirtualGuests (#1020)
Posted by Andrea Turli <no...@github.com>.
Closed #1020.
--
You are receiving this because you are subscribed to this thread.
Reply to this email directly or view it on GitHub:
https://github.com/jclouds/jclouds/pull/1020#event-823673856
Re: [jclouds/jclouds] reduce payload for GET VirtualGuests (#1020)
Posted by Ignasi Barrera <no...@github.com>.
145MB payload? WTF!
+1
--
You are receiving this because you are subscribed to this thread.
Reply to this email directly or view it on GitHub:
https://github.com/jclouds/jclouds/pull/1020#issuecomment-253741298